@@ -160,7 +160,7 @@ test.fp.balance <- function() {
 }
 
 test.fps.reader <- function() {
-  data.file <- file.path(.path.package(package="fingerprint"), "unitTests", "bits.fps")
+  data.file <- file.path(system.file("unitTests", "bits.fps", package="fingerprint"))
   fps <- fp.read(data.file, lf=fps.lf)
   checkEquals(323, length(fps))
 
